@@ -4,7 +4,7 @@ function (vertex.indices, vertices = NULL, name = ifelse(is.null(vertices),
     type = "Generator", index = 0, width = 2, color = "default", 
     factorClasses = validFactorClasses()) 
 {
-    prototype <- "GeneratorProto"
+    prototype <- "dg.Generator"
     x <- match(type, factorClasses[, 1])
     if (!is.null(x)) 
         prototype <- paste(factorClasses[, 2][x])
